@@ -115,6 +115,22 @@ EAPI void        elm_config_profile_dir_free(const char *p_dir);
  */
 EAPI Eina_List  *elm_config_profile_list_get(void);
 
+/**
+ * Get Elementary's list of available profiles including hidden ones.
+ *
+ * This gets a full list of profiles even with hidden names that should not
+ * be user-visible.
+ *
+ * @return The profiles list. List node data are the profile name
+ *         strings.
+ * @ingroup Profile
+ *
+ * @note One must free this list, after usage, with the function
+ *       elm_config_profile_list_free().
+ * @since 1.17
+ */
+EAPI Eina_List  *elm_config_profile_list_full_get(void);
+
 /**
  * Free Elementary's list of available profiles.
  *
@@ -124,6 +140,17 @@ EAPI Eina_List  *elm_config_profile_list_get(void);
  */
 EAPI void        elm_config_profile_list_free(Eina_List *l);
 
+/**
+ * Return if a profile of the given name exists
+ * 
+ * @return EINA_TRUE if the profile exists, or EINA_FALSE if not
+ * @param profile The profile's name
+ * @ingroup Profile
+ *
+ * @since 1.17
+ */
+EAPI Eina_Bool   elm_config_profile_exists(const char *profile);
+
 /**
  * Set Elementary's profile.
  *
@@ -137,6 +164,61 @@ EAPI void        elm_config_profile_list_free(Eina_List *l);
  */
 EAPI void        elm_config_profile_set(const char *profile);
 
+/**
+ * Take the current config and write it out to the named profile
+ *
+ * This will take the current in-memory config and write it out to the named
+ * profile specified by @p profile. This will not change profile for the
+ * application or make other processes switch profile.
+ * 
+ * @param profile The profile's name
+ * @ingroup Profile
+ *
+ * @since 1.17
+ */
+EAPI void        elm_config_profile_save(const char *profile);
+
+/**
+ * Add a new profile of the given name to be derived from the current profile
+ *
+ * This creates a new profile of name @p profile that will be derived from
+ * the currently used profile using the modification commands encoded in the
+ * @p derive_options string.
+ *
+ * At this point it is not expected that anyone would generally use this API
+ * except if you are a destktop environment and so the user base of this API
+ * will be enlightenment itself.
+ *
+ * @param profile The new profile's name
+ * @param derive_options A string of derive options detailing how to modify
+ *
+ * @see elm_config_profile_derived_del
+ * @ingroup Profile
+ *
+ * @since 1.17
+ */
+EAPI void        elm_config_profile_derived_add(const char *profile, const char *derive_options);
+
+/**
+ * Deletes a profile that is derived from the current one
+ *
+ * This deletes a derived profile added by elm_config_profile_derived_add().
+ * This will delete the profile of the given name @p profile that is derived
+ * from the current profile.
+ *
+ * At this point it is not expected that anyone would generally use this API
+ * except if you are a destktop environment and so the user base of this API
+ * will be enlightenment itself.
+ *
+ * @param profile The profile's name that is to be deleted
+ *
+ * @see elm_config_profile_derived_add
+ * @ingroup Profile
+ *
+ * @since 1.17
+ */
+EAPI void        elm_config_profile_derived_del(const char *profile);
+
 /**
  * @}
  */
@@ -215,6 +297,26 @@ EAPI double       elm_config_scroll_page_scroll_friction_get(void);
  */
 EAPI void         elm_config_scroll_page_scroll_friction_set(double friction);
 
+/**
+ * Get enable status of context menu disabled.
+ *
+ * @see elm_config_context_menu_disabled_set()
+ * @ingroup Entry
+ * @since 1.17
+ */
+EAPI Eina_Bool elm_config_context_menu_disabled_get(void);
+
+/**
+ * Enable or disable the context menu in entries.
+ *
+ * @param disabled disable context menu if @c EINA_TRUE, enable otherwise
+ *
+ * @see elm_config_context_menu_disabled_get()
+ * @ingroup Entry
+ * @since 1.17
+ */
+EAPI void elm_config_context_menu_disabled_set(Eina_Bool disabled);
+
 /**
  * Get the amount of inertia a scroller will impose at region bring
  * animations.
